Usage
=====

redpil is still heavily experimental. To use it in your project, make sure you
understand the limitations of each plugin. Then import the plugin you wish to
use with::

    from redpil.bmp import imread, imwrite
